// python wrapper for vtkAtom
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#if !defined(__APPLE__)
#include "vtkPython.h"
#undef _XOPEN_SOURCE /* Conflicts with standards.h.  */
#undef _THREAD_SAFE /* Conflicts with pthread.h.  */
#endif
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <vtksys/ios/sstream>
#include "vtkVector.h"
#include "vtkAtom.h"

#if defined(WIN32)
extern "C" { __declspec( dllexport ) void PyVTKAddFile_vtkAtom(PyObject *, const char *); }
#else
extern "C" { void PyVTKAddFile_vtkAtom(PyObject *, const char *); }
#endif

static const char **PyvtkAtom_Doc();


static PyObject *
PyvtkAtom_GetId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetId");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkIdType tempr = op->GetId();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkAtom_GetMolecule(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetMolecule");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkMolecule *tempr = op->GetMolecule();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkAtom_GetAtomicNumber(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetAtomicNumber");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    unsigned short tempr = op->GetAtomicNumber();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkAtom_SetAtomicNumber(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "SetAtomicNumber");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  unsigned short temp0;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
    {
    op->SetAtomicNumber(temp0);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkAtom_GetPosition_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetPosition");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  double temp0[3];
  double save0[3];
  const int size0 = 3;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
    {
    ap.SaveArray(temp0, save0, size0);

    op->GetPosition(temp0);

    if (ap.ArrayHasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
      {
      ap.SetArray(0, temp0, size0);
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}

static PyObject *
PyvtkAtom_GetPosition_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetPosition");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkVector3f tempr = op->GetPosition();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildSpecialObject(&tempr, "vtkVector3f");
      }
    }

  return result;
}

static PyObject *
PyvtkAtom_GetPosition(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
    {
    case 1:
      return PyvtkAtom_GetPosition_s1(self, args);
    case 0:
      return PyvtkAtom_GetPosition_s2(self, args);
    }

  vtkPythonArgs::ArgCountError(nargs, "GetPosition");
  return NULL;
}



static PyObject *
PyvtkAtom_SetPosition_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "SetPosition");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  float temp0[3];
  const int size0 = 3;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
    {
    op->SetPosition(temp0);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}

static PyObject *
PyvtkAtom_SetPosition_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "SetPosition");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  float temp0;
  float temp1;
  float temp2;
  PyObject *result = NULL;

  if (ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
    {
    op->SetPosition(temp0, temp1, temp2);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}

static PyObject *
PyvtkAtom_SetPosition_s3(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "SetPosition");
  void *vp = ap.GetSelfPointer(self);
  vtkAtom *op = static_cast<vtkAtom *>(vp);

  vtkVector3f *temp0 = NULL;
  PyObject *pobj0 = NULL;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkVector3f"))
    {
    op->SetPosition(*temp0);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  Py_XDECREF(pobj0);

  return result;
}

static PyMethodDef PyvtkAtom_SetPosition_Methods[] = {
  {NULL, PyvtkAtom_SetPosition_s1, 1,
   (char*)"O *f"},
  {NULL, PyvtkAtom_SetPosition_s3, 1,
   (char*)"O &vtkVector3f"},
  {NULL, NULL, 0, NULL}
};

static PyObject *
PyvtkAtom_SetPosition(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkAtom_SetPosition_Methods;
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
    {
    case 3:
      return PyvtkAtom_SetPosition_s2(self, args);
    case 1:
      return vtkPythonOverload::CallMethod(methods, self, args);
    }

  vtkPythonArgs::ArgCountError(nargs, "SetPosition");
  return NULL;
}


static PyMethodDef PyvtkAtom_Methods[] = {
  {(char*)"GetId", PyvtkAtom_GetId, 1,
   (char*)"V.GetId() -> int\nC++: vtkIdType GetId()\n\nReturn the Id used to identify this atom in the parent molecule.\n"},
  {(char*)"GetMolecule", PyvtkAtom_GetMolecule, 1,
   (char*)"V.GetMolecule() -> vtkMolecule\nC++: vtkMolecule *GetMolecule()\n\nReturn the parent molecule of this atom.\n"},
  {(char*)"GetAtomicNumber", PyvtkAtom_GetAtomicNumber, 1,
   (char*)"V.GetAtomicNumber() -> int\nC++: unsigned short GetAtomicNumber()\n\nGet/Set the atomic number of this atom\n"},
  {(char*)"SetAtomicNumber", PyvtkAtom_SetAtomicNumber, 1,
   (char*)"V.SetAtomicNumber(int)\nC++: void SetAtomicNumber(unsigned short atomicNum)\n\nGet/Set the atomic number of this atom\n"},
  {(char*)"GetPosition", PyvtkAtom_GetPosition, 1,
   (char*)"V.GetPosition([float, float, float])\nC++: void GetPosition(double pos[3])\nV.GetPosition() -> vtkVector3f\nC++: vtkVector3f GetPosition()\n\nGet/Set the position of this atom\n"},
  {(char*)"SetPosition", PyvtkAtom_SetPosition, 1,
   (char*)"V.SetPosition((float, float, float))\nC++: void SetPosition(const float pos[3])\nV.SetPosition(float, float, float)\nC++: void SetPosition(float x, float y, float z)\nV.SetPosition(vtkVector3f)\nC++: void SetPosition(const vtkVector3f &pos)\n\nGet/Set the position of this atom\n"},
  {NULL, NULL, 0, NULL}
};

#ifndef DECLARED_PyvtkAtom_Type
extern PyTypeObject PyvtkAtom_Type;
#define DECLARED_PyvtkAtom_Type
#endif


static PyObject *
PyvtkAtom_vtkAtom(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkAtom");

  vtkAtom *temp0 = NULL;
  PyObject *pobj0 = NULL;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkAtom"))
    {
    vtkAtom *op = new vtkAtom(*temp0);

    result = PyVTKSpecialObject_New("vtkAtom", op);
    }

  Py_XDECREF(pobj0);

  return result;
}

static PyMethodDef PyvtkAtom_vtkAtom_Methods[] = {
  {NULL, PyvtkAtom_vtkAtom, 1,
   (char*)"O &vtkAtom"},
  {NULL, NULL, 0, NULL}
};

static PyMethodDef PyvtkAtom_NewMethod = \
{ (char*)"vtkAtom", PyvtkAtom_vtkAtom, 1,
  (char*)"" };

#if PY_VERSION_HEX >= 0x02020000
static PyObject *
PyvtkAtom_New(PyTypeObject *, PyObject *args, PyObject *kwds)
{
  if (kwds && PyDict_Size(kwds))
    {
    PyErr_SetString(PyExc_TypeError,
                    "this function takes no keyword arguments");
    return NULL;
    }

  return PyvtkAtom_vtkAtom(NULL, args);
}
#endif

static void PyvtkAtom_Delete(PyObject *self)
{
  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;
  if (obj->vtk_ptr)
    {
    delete static_cast<vtkAtom *>(obj->vtk_ptr);
    }
#if PY_MAJOR_VERSION >= 2
  PyObject_Del(self);
#else
  PyMem_DEL(self);
#endif
}

static long PyvtkAtom_Hash(PyObject *self)
{
#if PY_VERSION_HEX >= 0x020600B2
  return PyObject_HashNotImplemented(self);
#else
  char text[256];
  sprintf(text, "unhashable type: '%s'", self->ob_type->tp_name);
  PyErr_SetString(PyExc_TypeError, text);
  return -1;
#endif
}

PyTypeObject PyvtkAtom_Type = {
  PyObject_HEAD_INIT(&PyType_Type)
  0,
  (char*)"vtkAtom", // tp_name
  sizeof(PyVTKSpecialObject), // tp_basicsize
  0, // tp_itemsize
  PyvtkAtom_Delete, // tp_dealloc
  0, // tp_print
  0, // tp_getattr
  0, // tp_setattr
  0, // tp_compare
  PyVTKSpecialObject_Repr, // tp_repr
  0, // tp_as_number
  0, // tp_as_sequence
  0, // tp_as_mapping
  PyvtkAtom_Hash, // tp_hash
  0, // tp_call
  0, // tp_str
#if PY_VERSION_HEX >= 0x02020000
  PyObject_GenericGetAttr, // tp_getattro
#else
  PyVTKSpecialObject_GetAttr, // tp_getattro
#endif
  0, // tp_setattro
  0, // tp_as_buffer
  Py_TPFLAGS_DEFAULT, // tp_flags
  0, // tp_doc
  0, // tp_traverse
  0, // tp_clear
  0, // tp_richcompare
  0, // tp_weaklistoffset
#if PY_VERSION_HEX >= 0x02020000
  0, // tp_iter
  0, // tp_iternext
  PyvtkAtom_Methods, // tp_methods
  0, // tp_members
  0, // tp_getset
  0, // tp_base
  0, // tp_dict
  0, // tp_descr_get
  0, // tp_descr_set
  0, // tp_dictoffset
  0, // tp_init
  0, // tp_alloc
  PyvtkAtom_New, // tp_new
#if PY_VERSION_HEX >= 0x02030000
  PyObject_Del, // tp_free
#else
  _PyObject_Del, // tp_free
#endif
  0, // tp_is_gc
  0, // tp_bases
  0, // tp_mro
  0, // tp_cache
  0, // tp_subclasses
  0, // tp_weaklist
#endif
  VTK_WRAP_PYTHON_SUPRESS_UNINITIALIZED
};

static void *PyvtkAtom_CCopy(const void *obj)
{
  if (obj)
    {
    return new vtkAtom(*static_cast<const vtkAtom*>(obj));
    }
  return 0;
}

static PyObject *PyvtkAtom_TypeNew(const char *)
{
  return PyVTKSpecialType_New(
    &PyvtkAtom_Type,
    PyvtkAtom_Methods,
    PyvtkAtom_vtkAtom_Methods,
    &PyvtkAtom_NewMethod,
    PyvtkAtom_Doc(), &PyvtkAtom_CCopy);
}

const char **PyvtkAtom_Doc()
{
  static const char *docstring[] = {
    "vtkAtom - convenience proxy for vtkMolecule\n\n",
    "\n\n",
    "V.vtkAtom(vtkAtom)\nC++: vtkAtom(const &vtkAtom)\n",
    NULL
  };

  return docstring;
}

void PyVTKAddFile_vtkAtom(
  PyObject *dict, const char *modulename)
{
  PyObject *o;
  o = PyvtkAtom_TypeNew(modulename);

  if (o && PyDict_SetItemString(dict, (char *)"vtkAtom", o) != 0)
    {
    Py_DECREF(o);
    }

}

