// python wrapper for vtkBond
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#if !defined(__APPLE__)
#include "vtkPython.h"
#undef _XOPEN_SOURCE /* Conflicts with standards.h.  */
#undef _THREAD_SAFE /* Conflicts with pthread.h.  */
#endif
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <vtksys/ios/sstream>
#include "vtkAtom.h"
#include "vtkBond.h"

#if defined(WIN32)
extern "C" { __declspec( dllexport ) void PyVTKAddFile_vtkBond(PyObject *, const char *); }
#else
extern "C" { void PyVTKAddFile_vtkBond(PyObject *, const char *); }
#endif

static const char **PyvtkBond_Doc();


static PyObject *
PyvtkBond_GetId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetId");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkIdType tempr = op->GetId();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetMolecule(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetMolecule");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkMolecule *tempr = op->GetMolecule();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetBeginAtomId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetBeginAtomId");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkIdType tempr = op->GetBeginAtomId();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetEndAtomId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetEndAtomId");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkIdType tempr = op->GetEndAtomId();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetBeginAtom(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetBeginAtom");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkAtom tempr = op->GetBeginAtom();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildSpecialObject(&tempr, "vtkAtom");
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetEndAtom(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetEndAtom");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    vtkAtom tempr = op->GetEndAtom();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildSpecialObject(&tempr, "vtkAtom");
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetOrder(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetOrder");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    unsigned short tempr = op->GetOrder();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkBond_GetLength(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(args, "GetLength");
  void *vp = ap.GetSelfPointer(self);
  vtkBond *op = static_cast<vtkBond *>(vp);

  PyObject *result = NULL;

  if (ap.CheckArgCount(0))
    {
    double tempr = op->GetLength();

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}

static PyMethodDef PyvtkBond_Methods[] = {
  {(char*)"GetId", PyvtkBond_GetId, 1,
   (char*)"V.GetId() -> int\nC++: vtkIdType GetId()\n\nReturn the Id used to identify this bond in the parent molecule.\n"},
  {(char*)"GetMolecule", PyvtkBond_GetMolecule, 1,
   (char*)"V.GetMolecule() -> vtkMolecule\nC++: vtkMolecule *GetMolecule()\n\nReturn the parent molecule of this bond.\n"},
  {(char*)"GetBeginAtomId", PyvtkBond_GetBeginAtomId, 1,
   (char*)"V.GetBeginAtomId() -> int\nC++: vtkIdType GetBeginAtomId()\n\nGet the starting / ending atom ids for this bond.\n"},
  {(char*)"GetEndAtomId", PyvtkBond_GetEndAtomId, 1,
   (char*)"V.GetEndAtomId() -> int\nC++: vtkIdType GetEndAtomId()\n\nGet the starting / ending atom ids for this bond.\n"},
  {(char*)"GetBeginAtom", PyvtkBond_GetBeginAtom, 1,
   (char*)"V.GetBeginAtom() -> vtkAtom\nC++: vtkAtom GetBeginAtom()\n\nGet a vtkAtom object that refers to the starting / ending atom\nfor this bond.\n"},
  {(char*)"GetEndAtom", PyvtkBond_GetEndAtom, 1,
   (char*)"V.GetEndAtom() -> vtkAtom\nC++: vtkAtom GetEndAtom()\n\nGet a vtkAtom object that refers to the starting / ending atom\nfor this bond.\n"},
  {(char*)"GetOrder", PyvtkBond_GetOrder, 1,
   (char*)"V.GetOrder() -> int\nC++: unsigned short GetOrder()\n\nGet the bond order for this bond.\n"},
  {(char*)"GetLength", PyvtkBond_GetLength, 1,
   (char*)"V.GetLength() -> float\nC++: double GetLength()\n\nGet the distance between the bonded atoms.\n\note This function is faster than vtkMolecule::GetBondLength and\nshould be used when possible.\n"},
  {NULL, NULL, 0, NULL}
};

#ifndef DECLARED_PyvtkBond_Type
extern PyTypeObject PyvtkBond_Type;
#define DECLARED_PyvtkBond_Type
#endif


static PyObject *
PyvtkBond_vtkBond(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "vtkBond");

  vtkBond *temp0 = NULL;
  PyObject *pobj0 = NULL;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetSpecialObject(temp0, pobj0, "vtkBond"))
    {
    vtkBond *op = new vtkBond(*temp0);

    result = PyVTKSpecialObject_New("vtkBond", op);
    }

  Py_XDECREF(pobj0);

  return result;
}

static PyMethodDef PyvtkBond_vtkBond_Methods[] = {
  {NULL, PyvtkBond_vtkBond, 1,
   (char*)"O &vtkBond"},
  {NULL, NULL, 0, NULL}
};

static PyMethodDef PyvtkBond_NewMethod = \
{ (char*)"vtkBond", PyvtkBond_vtkBond, 1,
  (char*)"" };

#if PY_VERSION_HEX >= 0x02020000
static PyObject *
PyvtkBond_New(PyTypeObject *, PyObject *args, PyObject *kwds)
{
  if (kwds && PyDict_Size(kwds))
    {
    PyErr_SetString(PyExc_TypeError,
                    "this function takes no keyword arguments");
    return NULL;
    }

  return PyvtkBond_vtkBond(NULL, args);
}
#endif

static void PyvtkBond_Delete(PyObject *self)
{
  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;
  if (obj->vtk_ptr)
    {
    delete static_cast<vtkBond *>(obj->vtk_ptr);
    }
#if PY_MAJOR_VERSION >= 2
  PyObject_Del(self);
#else
  PyMem_DEL(self);
#endif
}

static long PyvtkBond_Hash(PyObject *self)
{
#if PY_VERSION_HEX >= 0x020600B2
  return PyObject_HashNotImplemented(self);
#else
  char text[256];
  sprintf(text, "unhashable type: '%s'", self->ob_type->tp_name);
  PyErr_SetString(PyExc_TypeError, text);
  return -1;
#endif
}

PyTypeObject PyvtkBond_Type = {
  PyObject_HEAD_INIT(&PyType_Type)
  0,
  (char*)"vtkBond", // tp_name
  sizeof(PyVTKSpecialObject), // tp_basicsize
  0, // tp_itemsize
  PyvtkBond_Delete, // tp_dealloc
  0, // tp_print
  0, // tp_getattr
  0, // tp_setattr
  0, // tp_compare
  PyVTKSpecialObject_Repr, // tp_repr
  0, // tp_as_number
  0, // tp_as_sequence
  0, // tp_as_mapping
  PyvtkBond_Hash, // tp_hash
  0, // tp_call
  0, // tp_str
#if PY_VERSION_HEX >= 0x02020000
  PyObject_GenericGetAttr, // tp_getattro
#else
  PyVTKSpecialObject_GetAttr, // tp_getattro
#endif
  0, // tp_setattro
  0, // tp_as_buffer
  Py_TPFLAGS_DEFAULT, // tp_flags
  0, // tp_doc
  0, // tp_traverse
  0, // tp_clear
  0, // tp_richcompare
  0, // tp_weaklistoffset
#if PY_VERSION_HEX >= 0x02020000
  0, // tp_iter
  0, // tp_iternext
  PyvtkBond_Methods, // tp_methods
  0, // tp_members
  0, // tp_getset
  0, // tp_base
  0, // tp_dict
  0, // tp_descr_get
  0, // tp_descr_set
  0, // tp_dictoffset
  0, // tp_init
  0, // tp_alloc
  PyvtkBond_New, // tp_new
#if PY_VERSION_HEX >= 0x02030000
  PyObject_Del, // tp_free
#else
  _PyObject_Del, // tp_free
#endif
  0, // tp_is_gc
  0, // tp_bases
  0, // tp_mro
  0, // tp_cache
  0, // tp_subclasses
  0, // tp_weaklist
#endif
  VTK_WRAP_PYTHON_SUPRESS_UNINITIALIZED
};

static void *PyvtkBond_CCopy(const void *obj)
{
  if (obj)
    {
    return new vtkBond(*static_cast<const vtkBond*>(obj));
    }
  return 0;
}

static PyObject *PyvtkBond_TypeNew(const char *)
{
  return PyVTKSpecialType_New(
    &PyvtkBond_Type,
    PyvtkBond_Methods,
    PyvtkBond_vtkBond_Methods,
    &PyvtkBond_NewMethod,
    PyvtkBond_Doc(), &PyvtkBond_CCopy);
}

const char **PyvtkBond_Doc()
{
  static const char *docstring[] = {
    "vtkBond - convenience proxy for vtkMolecule\n\n",
    "\n\n",
    "V.vtkBond(vtkBond)\nC++: vtkBond(const &vtkBond)\n",
    NULL
  };

  return docstring;
}

void PyVTKAddFile_vtkBond(
  PyObject *dict, const char *modulename)
{
  PyObject *o;
  o = PyvtkBond_TypeNew(modulename);

  if (o && PyDict_SetItemString(dict, (char *)"vtkBond", o) != 0)
    {
    Py_DECREF(o);
    }

}

