// python wrapper for vtkGraphWeightFilter
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#if !defined(__APPLE__)
#include "vtkPython.h"
#undef _XOPEN_SOURCE /* Conflicts with standards.h.  */
#undef _THREAD_SAFE /* Conflicts with pthread.h.  */
#endif
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <vtksys/ios/sstream>
#include "vtkGraphWeightFilter.h"

#if defined(WIN32)
extern "C" { __declspec( dllexport ) void PyVTKAddFile_vtkGraphWeightFilter(PyObject *, const char *); }
#else
extern "C" { void PyVTKAddFile_vtkGraphWeightFilter(PyObject *, const char *); }
#endif
#if defined(WIN32)
extern "C" { __declspec( dllexport ) PyObject *PyVTKClass_vtkGraphWeightFilterNew(const char *); }
#else
extern "C" { PyObject *PyVTKClass_vtkGraphWeightFilterNew(const char *); }
#endif

#ifndef DECLARED_PyVTKClass_vtkGraphAlgorithmNew
extern "C" { PyObject *PyVTKClass_vtkGraphAlgorithmNew(const char *); }
#define DECLARED_PyVTKClass_vtkGraphAlgorithmNew
#endif

static const char **PyvtkGraphWeightFilter_Doc();


static PyObject *
PyvtkGraphWeightFilter_GetClassName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClassName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGraphWeightFilter *op = static_cast<vtkGraphWeightFilter *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    const char *tempr = (ap.IsBound() ?
      op->GetClassName() :
      op->vtkGraphWeightFilter::GetClassName());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkGraphWeightFilter_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGraphWeightFilter *op = static_cast<vtkGraphWeightFilter *>(vp);

  char *temp0 = NULL;
  PyObject *result = NULL;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
    {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGraphWeightFilter::IsA(temp0));

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkGraphWeightFilter_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGraphWeightFilter *op = static_cast<vtkGraphWeightFilter *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    vtkGraphWeightFilter *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGraphWeightFilter::NewInstance());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
        {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
        }
      }
    }

  return result;
}

static PyMethodDef PyvtkGraphWeightFilter_Methods[] = {
  {(char*)"GetClassName", PyvtkGraphWeightFilter_GetClassName, 1,
   (char*)"V.GetClassName() -> string\nC++: const char *GetClassName()\n\n"},
  {(char*)"IsA", PyvtkGraphWeightFilter_IsA, 1,
   (char*)"V.IsA(string) -> int\nC++: int IsA(const char *name)\n\n"},
  {(char*)"NewInstance", PyvtkGraphWeightFilter_NewInstance, 1,
   (char*)"V.NewInstance() -> vtkGraphWeightFilter\nC++: vtkGraphWeightFilter *NewInstance()\n\n"},
  {NULL, NULL, 0, NULL}
};

PyObject *PyVTKClass_vtkGraphWeightFilterNew(const char *modulename)
{
  PyObject *cls = PyVTKClass_New(NULL,
    PyvtkGraphWeightFilter_Methods,
    "vtkGraphWeightFilter", modulename,
    NULL, NULL,
    PyvtkGraphWeightFilter_Doc(),
    PyVTKClass_vtkGraphAlgorithmNew(modulename));
  return cls;
}

const char **PyvtkGraphWeightFilter_Doc()
{
  static const char *docstring[] = {
    "vtkGraphWeightFilter - Base class for filters that weight graph\n\n",
    "Superclass: vtkGraphAlgorithm\n\n",
    "vtkGraphWeightFilter is the abstract base class that provides an\ninterface for classes that apply weights to graph edges. The weights\nare added as a vtkFloatArray named \"Weights.\" The ComputeWeight\nfunction must be implemented to provide the function of two vertices\nwhich determines the weight of each edge. The CheckRequirements\nfunction can be implemented if you wish to ensure that the input\ngrap",
    "h has all of the properties that will be required by the\nComputeWeight function.\n\n",
    NULL
  };

  return docstring;
}

void PyVTKAddFile_vtkGraphWeightFilter(
  PyObject *dict, const char *modulename)
{
  PyObject *o;
  o = PyVTKClass_vtkGraphWeightFilterNew(modulename);

  if (o && PyDict_SetItemString(dict, (char *)"vtkGraphWeightFilter", o) != 0)
    {
    Py_DECREF(o);
    }

}

