// python wrapper for vtkFeatureDictionary
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#if !defined(__APPLE__)
#include "vtkPython.h"
#undef _XOPEN_SOURCE /* Conflicts with standards.h.  */
#undef _THREAD_SAFE /* Conflicts with pthread.h.  */
#endif
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <vtksys/ios/sstream>
#include "vtkFeatureDictionary.h"

#if defined(WIN32)
extern "C" { __declspec( dllexport ) void PyVTKAddFile_vtkFeatureDictionary(PyObject *, const char *); }
#else
extern "C" { void PyVTKAddFile_vtkFeatureDictionary(PyObject *, const char *); }
#endif
#if defined(WIN32)
extern "C" { __declspec( dllexport ) PyObject *PyVTKClass_vtkFeatureDictionaryNew(const char *); }
#else
extern "C" { PyObject *PyVTKClass_vtkFeatureDictionaryNew(const char *); }
#endif

#ifndef DECLARED_PyVTKClass_vtkTableAlgorithmNew
extern "C" { PyObject *PyVTKClass_vtkTableAlgorithmNew(const char *); }
#define DECLARED_PyVTKClass_vtkTableAlgorithmNew
#endif

static const char **PyvtkFeatureDictionary_Doc();


static PyObject *
PyvtkFeatureDictionary_GetClassName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClassName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFeatureDictionary *op = static_cast<vtkFeatureDictionary *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    const char *tempr = (ap.IsBound() ?
      op->GetClassName() :
      op->vtkFeatureDictionary::GetClassName());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkFeatureDictionary_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFeatureDictionary *op = static_cast<vtkFeatureDictionary *>(vp);

  char *temp0 = NULL;
  PyObject *result = NULL;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
    {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkFeatureDictionary::IsA(temp0));

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkFeatureDictionary_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkFeatureDictionary *op = static_cast<vtkFeatureDictionary *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    vtkFeatureDictionary *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkFeatureDictionary::NewInstance());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
        {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
        }
      }
    }

  return result;
}


static PyObject *
PyvtkFeatureDictionary_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObject *temp0 = NULL;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObject"))
    {
    vtkFeatureDictionary *tempr = vtkFeatureDictionary::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      }
    }

  return result;
}

static PyMethodDef PyvtkFeatureDictionary_Methods[] = {
  {(char*)"GetClassName", PyvtkFeatureDictionary_GetClassName, 1,
   (char*)"V.GetClassName() -> string\nC++: const char *GetClassName()\n\n"},
  {(char*)"IsA", PyvtkFeatureDictionary_IsA, 1,
   (char*)"V.IsA(string) -> int\nC++: int IsA(const char *name)\n\n"},
  {(char*)"NewInstance", PyvtkFeatureDictionary_NewInstance, 1,
   (char*)"V.NewInstance() -> vtkFeatureDictionary\nC++: vtkFeatureDictionary *NewInstance()\n\n"},
  {(char*)"SafeDownCast", PyvtkFeatureDictionary_SafeDownCast, 1,
   (char*)"V.SafeDownCast(vtkObject) -> vtkFeatureDictionary\nC++: vtkFeatureDictionary *SafeDownCast(vtkObject* o)\n\n"},
  {NULL, NULL, 0, NULL}
};

static vtkObjectBase *PyvtkFeatureDictionary_StaticNew()
{
  return vtkFeatureDictionary::New();
}

PyObject *PyVTKClass_vtkFeatureDictionaryNew(const char *modulename)
{
  PyObject *cls = PyVTKClass_New(&PyvtkFeatureDictionary_StaticNew,
    PyvtkFeatureDictionary_Methods,
    "vtkFeatureDictionary", modulename,
    NULL, NULL,
    PyvtkFeatureDictionary_Doc(),
    PyVTKClass_vtkTableAlgorithmNew(modulename));
  return cls;
}

const char **PyvtkFeatureDictionary_Doc()
{
  static const char *docstring[] = {
    "vtkFeatureDictionary - Generates a dictionary of unique terms.\n\n",
    "Superclass: vtkTableAlgorithm\n\n",
    "vtkFeatureDictionary reorganizes a table containing (potentially\nduplicated) terms into a dictionary where every term appears exactly\nonce.\n\nInputs:\n  Input port 0: (required) A vtkTable containing \"type\" and \"text\"\ncolumns.\n\nOutputs:\n  Output port 0: A vtkTable containing \"type\" and \"text\" columns\nwhere each\n    input term appears exactly once.\n\nUse SetInputArrayToProcess(0, ...) to specify the i",
    "nput \"type\" array.\nUse SetInputArrayToProcess(1, ...) to specify the input \"text\" array.\n\nSee Also:\n\nvtkPTermDictionary\n\nThanks:\n\nDeveloped by Timothy M. Shead (tshead@sandia.gov) at Sandia National\nLaboratories.\n\n",
    NULL
  };

  return docstring;
}

void PyVTKAddFile_vtkFeatureDictionary(
  PyObject *dict, const char *modulename)
{
  PyObject *o;
  o = PyVTKClass_vtkFeatureDictionaryNew(modulename);

  if (o && PyDict_SetItemString(dict, (char *)"vtkFeatureDictionary", o) != 0)
    {
    Py_DECREF(o);
    }

}

