// python wrapper for vtkTokenizer
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#if !defined(__APPLE__)
#include "vtkPython.h"
#undef _XOPEN_SOURCE /* Conflicts with standards.h.  */
#undef _THREAD_SAFE /* Conflicts with pthread.h.  */
#endif
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <vtksys/ios/sstream>
#include "vtkTokenizer.h"

#if defined(WIN32)
extern "C" { __declspec( dllexport ) void PyVTKAddFile_vtkTokenizer(PyObject *, const char *); }
#else
extern "C" { void PyVTKAddFile_vtkTokenizer(PyObject *, const char *); }
#endif
#if defined(WIN32)
extern "C" { __declspec( dllexport ) PyObject *PyVTKClass_vtkTokenizerNew(const char *); }
#else
extern "C" { PyObject *PyVTKClass_vtkTokenizerNew(const char *); }
#endif

#ifndef DECLARED_PyVTKClass_vtkTableAlgorithmNew
extern "C" { PyObject *PyVTKClass_vtkTableAlgorithmNew(const char *); }
#define DECLARED_PyVTKClass_vtkTableAlgorithmNew
#endif

static const char **PyvtkTokenizer_Doc();


static PyObject *
PyvtkTokenizer_GetClassName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClassName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    const char *tempr = (ap.IsBound() ?
      op->GetClassName() :
      op->vtkTokenizer::GetClassName());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  char *temp0 = NULL;
  PyObject *result = NULL;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
    {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkTokenizer::IsA(temp0));

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildValue(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    vtkTokenizer *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkTokenizer::NewInstance());

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
        {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
        }
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObject *temp0 = NULL;
  PyObject *result = NULL;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObject"))
    {
    vtkTokenizer *tempr = vtkTokenizer::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildVTKObject(tempr);
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_AddDroppedDelimiters(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddDroppedDelimiters");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  unsigned int temp0;
  unsigned int temp1;
  PyObject *result = NULL;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
    {
    if (ap.IsBound())
      {
      op->AddDroppedDelimiters(temp0, temp1);
      }
    else
      {
      op->vtkTokenizer::AddDroppedDelimiters(temp0, temp1);
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_AddKeptDelimiters(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddKeptDelimiters");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  unsigned int temp0;
  unsigned int temp1;
  PyObject *result = NULL;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
    {
    if (ap.IsBound())
      {
      op->AddKeptDelimiters(temp0, temp1);
      }
    else
      {
      op->vtkTokenizer::AddKeptDelimiters(temp0, temp1);
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_DropPunctuation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "DropPunctuation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->DropPunctuation();
      }
    else
      {
      op->vtkTokenizer::DropPunctuation();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_DropWhitespace(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "DropWhitespace");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->DropWhitespace();
      }
    else
      {
      op->vtkTokenizer::DropWhitespace();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_KeepPunctuation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "KeepPunctuation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->KeepPunctuation();
      }
    else
      {
      op->vtkTokenizer::KeepPunctuation();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_KeepWhitespace(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "KeepWhitespace");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->KeepWhitespace();
      }
    else
      {
      op->vtkTokenizer::KeepWhitespace();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_KeepLogosyllabic(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "KeepLogosyllabic");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->KeepLogosyllabic();
      }
    else
      {
      op->vtkTokenizer::KeepLogosyllabic();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_ClearDroppedDelimiters(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClearDroppedDelimiters");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->ClearDroppedDelimiters();
      }
    else
      {
      op->vtkTokenizer::ClearDroppedDelimiters();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}


static PyObject *
PyvtkTokenizer_ClearKeptDelimiters(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClearKeptDelimiters");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkTokenizer *op = static_cast<vtkTokenizer *>(vp);

  PyObject *result = NULL;

  if (op && ap.CheckArgCount(0))
    {
    if (ap.IsBound())
      {
      op->ClearKeptDelimiters();
      }
    else
      {
      op->vtkTokenizer::ClearKeptDelimiters();
      }

    if (!ap.ErrorOccurred())
      {
      result = ap.BuildNone();
      }
    }

  return result;
}

static PyMethodDef PyvtkTokenizer_Methods[] = {
  {(char*)"GetClassName", PyvtkTokenizer_GetClassName, 1,
   (char*)"V.GetClassName() -> string\nC++: const char *GetClassName()\n\n"},
  {(char*)"IsA", PyvtkTokenizer_IsA, 1,
   (char*)"V.IsA(string) -> int\nC++: int IsA(const char *name)\n\n"},
  {(char*)"NewInstance", PyvtkTokenizer_NewInstance, 1,
   (char*)"V.NewInstance() -> vtkTokenizer\nC++: vtkTokenizer *NewInstance()\n\n"},
  {(char*)"SafeDownCast", PyvtkTokenizer_SafeDownCast, 1,
   (char*)"V.SafeDownCast(vtkObject) -> vtkTokenizer\nC++: vtkTokenizer *SafeDownCast(vtkObject* o)\n\n"},
  {(char*)"AddDroppedDelimiters", PyvtkTokenizer_AddDroppedDelimiters, 1,
   (char*)"V.AddDroppedDelimiters(int, int)\nC++: void AddDroppedDelimiters(vtkUnicodeString::value_type begin,\n     vtkUnicodeString::value_type end)\n\nAdds the half-open range of Unicode characters [begin, end) to\nthe set of \"dropped\" delimiters.\n"},
  {(char*)"AddKeptDelimiters", PyvtkTokenizer_AddKeptDelimiters, 1,
   (char*)"V.AddKeptDelimiters(int, int)\nC++: void AddKeptDelimiters(vtkUnicodeString::value_type begin,\n    vtkUnicodeString::value_type end)\n\nAdds the half-open range of Unicode characters [begin, end) to\nthe set of \"kept\" delimiters.\n"},
  {(char*)"DropPunctuation", PyvtkTokenizer_DropPunctuation, 1,
   (char*)"V.DropPunctuation()\nC++: void DropPunctuation()\n\nConvenience functions to specify delimiters, mainly intended for\nuse from Python and the ParaView server manager.  C++ developers\nare strongly encouraged to use AddDroppedDelimiters(...) and\nAddKeptDelimiters(...) instead.\n"},
  {(char*)"DropWhitespace", PyvtkTokenizer_DropWhitespace, 1,
   (char*)"V.DropWhitespace()\nC++: void DropWhitespace()\n\nConvenience functions to specify delimiters, mainly intended for\nuse from Python and the ParaView server manager.  C++ developers\nare strongly encouraged to use AddDroppedDelimiters(...) and\nAddKeptDelimiters(...) instead.\n"},
  {(char*)"KeepPunctuation", PyvtkTokenizer_KeepPunctuation, 1,
   (char*)"V.KeepPunctuation()\nC++: void KeepPunctuation()\n\nConvenience functions to specify delimiters, mainly intended for\nuse from Python and the ParaView server manager.  C++ developers\nare strongly encouraged to use AddDroppedDelimiters(...) and\nAddKeptDelimiters(...) instead.\n"},
  {(char*)"KeepWhitespace", PyvtkTokenizer_KeepWhitespace, 1,
   (char*)"V.KeepWhitespace()\nC++: void KeepWhitespace()\n\nConvenience functions to specify delimiters, mainly intended for\nuse from Python and the ParaView server manager.  C++ developers\nare strongly encouraged to use AddDroppedDelimiters(...) and\nAddKeptDelimiters(...) instead.\n"},
  {(char*)"KeepLogosyllabic", PyvtkTokenizer_KeepLogosyllabic, 1,
   (char*)"V.KeepLogosyllabic()\nC++: void KeepLogosyllabic()\n\nConvenience functions to specify delimiters, mainly intended for\nuse from Python and the ParaView server manager.  C++ developers\nare strongly encouraged to use AddDroppedDelimiters(...) and\nAddKeptDelimiters(...) instead.\n"},
  {(char*)"ClearDroppedDelimiters", PyvtkTokenizer_ClearDroppedDelimiters, 1,
   (char*)"V.ClearDroppedDelimiters()\nC++: void ClearDroppedDelimiters()\n\nClears the set of \"dropped\" delimiters.\n"},
  {(char*)"ClearKeptDelimiters", PyvtkTokenizer_ClearKeptDelimiters, 1,
   (char*)"V.ClearKeptDelimiters()\nC++: void ClearKeptDelimiters()\n\nClears the set of \"kept\" delimiters.\n"},
  {NULL, NULL, 0, NULL}
};

static vtkObjectBase *PyvtkTokenizer_StaticNew()
{
  return vtkTokenizer::New();
}

PyObject *PyVTKClass_vtkTokenizerNew(const char *modulename)
{
  PyObject *cls = PyVTKClass_New(&PyvtkTokenizer_StaticNew,
    PyvtkTokenizer_Methods,
    "vtkTokenizer", modulename,
    NULL, NULL,
    PyvtkTokenizer_Doc(),
    PyVTKClass_vtkTableAlgorithmNew(modulename));
  return cls;
}

const char **PyvtkTokenizer_Doc()
{
  static const char *docstring[] = {
    "vtkTokenizer - Converts a document collection into a term collection.\n\n",
    "Superclass: vtkTableAlgorithm\n\n",
    "Given an artifact table containing text documents, splits each\ndocument into its component tokens, producing a feature table\ncontaining the results.\n\nTokenization is performed by splitting input text into tokens based\non character delimiters.  Delimiters are divided into two categories:\n\"dropped\" and \"kept\".  \"Dropped\" delimiters are discarded from the\noutput, while \"kept\" delimiters are retained ",
    "in the output as\nindividual tokens.  Initially, vtkTokenizer has no delimiters\ndefined, so you must set some delimiters before use.\n\nUsers can reset and append to the lists of delimiters for each\ncategory. Delimiters are specified as half-open ranges of Unicode\ncode points.  This makes it easy to tokenize logosyllabic scripts\nsuch as Chinese, Korean, and Japanese by specifying an entire range\nof l",
    "ogograms as \"kept\" delimiters, so that individual glyphs become\ntokens.\n\nInputs:\n  Input port 0: (required) A vtkTable containing zero-to-many\n\"documents\", with\n    one document per table row, a vtkIdTypeArray column containing\ndocument ids,\n    and a vtkUnicodeStringArray column containing the contents of\neach document.\n  Input port 1: (optional) A vtkTable containing zero-to-many\ndocument ranges",
    "\n    to be processed, with one range per table row, a vtkIdTypeArray\ncolumn\n    containing document ids, a vtkIdTypeArray containing begin\noffsets, and a\n    vtkIdTypeArray column containing end offsets.  If input port 1 is\nleft\n    unconnected, the filter will automatically process the entire\ncontents of\n    every input document.\n\nOutputs:\n  Output port 0: A vtkTable containing \"document\", \"begin",
    "\", \"end\",\n\"type\", and\n    \"text\" columns.\n\nUse SetInputArrayToProcess(0, ...) to specify the input table column\nthat contains document ids (must be a vtkIdTypeArray).  Default:\n\"document\"\n\nUse SetInputArrayToProcess(1, ...) to specify the input table column\nthat contains document contents (must be a vtkUnicodeStringArray). \nDefault: \"text\"\n\nUse SetInputArrayToProcess(2, 1, ...) to specify the inpu",
    "t table\ncolumn that contains range document ids (must be a vtkIdTypeArray). \nDefaults to \"document\".\n\nUse SetInputArrayToProcess(3, 1, ...) to specify the input table\ncolumn that contains range begin offsets (must be a vtkIdTypeArray). \nDefaults to \"begin\".\n\nUse SetInputArrayToProcess(4, 1, ...) to specify the input table\ncolumn that contains range end offsets (must be a vtkIdTypeArray). \nDefaults",
    " to \"end\".\n\nThanks:\n\nDeveloped by Timothy M. Shead (tshead@sandia.gov) at Sandia National\nLaboratories.\n\n",
    NULL
  };

  return docstring;
}

void PyVTKAddFile_vtkTokenizer(
  PyObject *dict, const char *modulename)
{
  PyObject *o;
  o = PyVTKClass_vtkTokenizerNew(modulename);

  if (o && PyDict_SetItemString(dict, (char *)"vtkTokenizer", o) != 0)
    {
    Py_DECREF(o);
    }

}

